Welcome to Operalib’s documentation! — Operalib 0.1.0 documentation

# Welcome to Operalib’s documentation!

Operalib is a library for structured learning and prediction for python based on operator-valued kernels (OVKs). OVKs are an extension of scalar kernels to operator-valued kernels. The idea is to predict silmultaneously several targets while, for instance, encoding the output structure with the operator-valued kernel.

We aim at providing an easy-to-use standard implementation of operator-valued kernel methods. Operalib is designed for compatilibity to scikit-learn interface and conventions. It uses numpy, and scipy as underlying libraries.

The project is developed by the AROBAS group of the IBISC laboratory of the University of Evry, France.

> - API Documentation
> - General examples
> - Contact

See the README for additional information.

# Indices and tables

- Index
- Module Index
- Search Page